<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="申请人">
              <el-select v-model="querys[1].value" clearable filterable allow-create style="width: 100%"
                placeholder="请选择申请人员">
                <el-option v-for="item in userSelectOptions" :key="item.id" :label="item.fullname" :value="item.id">
                  <span style="float: left">{{ item.fullname }}</span>
                  <span style="
                                            float: right;
                                            color: #8492a6;
                                            font-size: 13px;
                                        ">{{ item.orgName }}</span>
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="申请日期">
              <el-date-picker v-model="querys[2].value" type="date" value-format="yyyy-MM-dd" placeholder="选择日期">
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="申请状态">
              <el-select v-model="querys[3].value" placeholder="请选择">
                <el-option v-for="item in options" :key="item.value" :label="item.label" :value="item.value">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="申请标题">
              <el-input v-model="querys[0].value" clearable placeholder="请输入申请标题" />
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content"></div>
      <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="index" width="55" label="序号" />
        <el-table-column prop="code" label="申请单号" show-overflow-tooltip />
        <el-table-column prop="applyTitle" label="申请标题" min-width="180" show-overflow-tooltip />
        <el-table-column prop="applicationDeptName" min-width="100" label="申请部门" show-overflow-tooltip />
        <el-table-column prop="applicantName" min-width="100" label="申请人" show-overflow-tooltip />
        <el-table-column prop="applicationDate" min-width="100" label="申请日期" show-overflow-tooltip />
        <el-table-column label="领用状态" min-width="100" prop="status">
          <template slot-scope="scope">
            <el-tag v-if="scope.row.status == '1'" type="info">未领用</el-tag>
            <el-tag v-if="scope.row.status == '2'" type="success">已领用</el-tag>
          </template>
        </el-table-column>
        <el-table-column label="操作">
          <template slot-scope="scope">
            <el-button v-if="scope.row.status == '1'" size="mini" type="primary" plain
              @click="handleRecipientsDialog(scope.row)">领用物资</el-button>
            <el-button v-if="scope.row.status == '2'" size="mini" type="primary" plain
              @click="handleDetailDialog(scope.row)">领用详情</el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
        :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="total"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" />
    </div>
    <MaterialOutofWareHoseManageDialog ref="formModal" />
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import materialOutWarehouseManage from '@/api/manager/material/materialOutWarehouseManage.js'
import MaterialOutofWareHoseManageDialog from '@/views/Manage/material/components/MaterialOutofWareHoseManageDialog.vue'
import CommonApi from '@/views/Manage/CommonApi.js'
export default {
  name: 'MaterialOutofWareHoseManage',
  components: {
    MaterialOutofWareHoseManageDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      userSelectOptions: [],
      options: [
        {
          value: '2',
          label: '未领用'
        },
        {
          value: '3',
          label: '已领用'
        }
      ],
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'applyTitle',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'applicant',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'applicationDate',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'status',
          relation: 'AND',
          value: ''
        }
      ]
    }
  },
  created() {
    this.commonApiData()
  },
  mounted() { },
  methods: {
    commonApiData() {
      CommonApi.loadSelectOptions(
        {
          name: 'manageCommonService.getAllUsers',
          query: '96240625-934F-490B-8AA6-0BC775B18468'
        },
        res => {
          this.userSelectOptions = res
        }
      )
    },
    // 重置
    clearQuerys() {
      this.querys.forEach(item => {
        item.value = ''
      })
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []

      this.querys.forEach(item => {
        if (item.value) this.queryParam.querys.push(item)
      })

      this.queryParam.sorter = [
        {
          direction: 'DESC',
          property: 'create_time_'
        }
      ]

      materialOutWarehouseManage.loadOutWarehouse(this.queryParam, res => {
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    //操作
    handleRecipientsDialog(row) {
      this.$refs.formModal.recipients(row)
    },
    //操作
    handleDetailDialog(row) {
      this.$refs.formModal.detail(row)
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
